@@ -1,3 +1,19 @@
+##  Copyright (C) 2010 John Verzani
+##
+##  This program is free software; you can redistribute it and/or modify
+##  it under the terms of the GNU General Public License as published by
+##  the Free Software Foundation; either version 2 of the License, or
+##  (at your option) any later version.
+##
+##  This program is distributed in the hope that it will be useful,
+##  but WITHOUT ANY WARRANTY; without even the implied warranty of
+##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+##  GNU General Public License for more details.
+##
+##  A copy of the GNU General Public License is available at
+##  http://www.r-project.org/Licenses/
+
+
 ## use EditorGridView to edit a data frame
 
 ## working
@@ -13,25 +29,27 @@
 ## names<-, names for headers
 ## integrate -- filter fun: maybe never
 
+     
 gdf <- function(items = NULL, name = deparse(substitute(items)),
                 do.subset = FALSE,
-                container = NULL, ...) {
+                container = NULL, ...,
+                width=200, height=200   # gWidgetsWWW defaults
+                ) {
 
   
-  widget <- EXTComponentWithStore$new(toplevel=container$toplevel,
+  widget <- EXTComponentDfStore$new(toplevel=container$toplevel,
                                       ..name = name,
-                                      ..do.subset = do.subset
+                                      ..do.subset = do.subset,
+                                    ..width = width,
+                                    ..height= height
                                       )
   class(widget) <- c("gDf",class(widget))
 
-  ## process width, height if given
-  theArgs <- list(...)
-  if(!is.null(theArgs$width)) widget$..width <- theArgs$width
-  if(!is.null(theArgs$height)) widget$..height <- theArgs$height
+
 
   
   ## set up store
-  store <- EXTStore$new()
+  store <- EXTStore$new(toplevel=container$toplevel)
   store$ID <- container$newID()       # set ID
 
   ## load in items
@@ -39,46 +57,36 @@ gdf <- function(items = NULL, name = deparse(substitute(items)),
   
   store$data <- items
   widget$..store <- store
-
+  widget$..data <- numeric(0)           # we store indices
   ## set up widget
 
-  widget$getValues <- function(., ...) {
-    ## transport puts new values into
-    ## "gWidgetIDX.R.C" where R = row, C = column
-    ## all values stored as characters!
 
-    ## first we pt the new values into the data frame
-    items <- .$..store$data
-
-    newVals <- ls(pat = String("^") + .$ID + '\\.', envir=.$toplevel)
-    if(length(newVals) > 0) {
-      for(i in newVals) {
-        tmp <- unlist(strsplit(i, "\\."))
-        row <- as.numeric(tmp[2])
-        col <- as.numeric(tmp[3])
-        value <- get(i, envir=.$toplevel)
-
-        colType <- class(items[,col, drop=TRUE])[1]
-
-        value <- switch(colType,
-                        "numeric" = as.numeric(value),
-                        "integer" = as.numeric(value),
-                        "logical" = as.logical(value),
-                        as.character(value))
-        items[row,col] <- value
-
-        rm(list = i, envir=.$toplevel)                           # remove
-      }
-    }
-
-    ## update data store
-    .$..store$data <- items
-
-    return(items)
+  widget$assignValue <- function(., value) {
+    ## assign value. Here values i list value, row, column
+    coerceValue <- function(x, value) UseMethod("coerceValue")
+    coerceValue.default <- function(x, value) format(value)
+    coerceValue.character <- function(x, value) as.character(value)
+    coerceValue.integer <- function(x, value) as.integer(value)
+    coerceValue.numeric <- function(x, value) as.numeric(value)
+    coerceValue.logical <- function(x, value)  as.logical(toupper(value))
+    coerceValue.factor <- function(x, value) ifelse(value %in% levels(x), value, NA)
+  
 
+    df <- .$..store$data
+    i <- as.numeric(value[[2]])
+    j <- as.numeric(value[[3]])
+    val <- value[[1]]
+    df[i,j] <- coerceValue(df[[j]], val)
+    .$..store$data <- df
   }
 
-  
+  ## return data frame
+  widget$getValues <- function(., ...) {
+    items <- .$..store$data
+    return(items)
+  }
+
+  ## transport
   widget$transportSignal <- c("afteredit")
   widget$transportValue <- function(.,...) {
     ## XXX use id.row.col <- value to update cell
@@ -89,9 +97,7 @@ gdf <- function(items = NULL, name = deparse(substitute(items)),
     ## write to id.row.col
 
     out <- String() +
-      'var rowIndex = e.row + 1; var colIndex = e.column + 1;' +
-        'var id = "' + .$ID + '" + "." + rowIndex.toString() + "." + colIndex.toString();' +
-          '_transportToR(id, Ext.util.JSON.encode({value:e.value}));'
+      sprintf("_transportToR('%s', Ext.util.JSON.encode({value:e.value,row:e.row + 1, column:e.column+1}));", .$ID)
     return(out)
   }
 
@@ -119,6 +125,17 @@ gdf <- function(items = NULL, name = deparse(substitute(items)),
     return(out)
   }
 
+  ## The map editor
+  widget$mapEditor <- function(., x) {
+    type <- class(x)[1]
+    switch(type,
+           "integer" = ",editor: new Ext.form.NumberField({allowBlank: true,allowDecimals: false,nanText: 'NA'})",
+           "numeric" = ",editor: new Ext.form.NumberField({allowBlank: true,allowDecimals: true,nanText: 'NA'})",
+           "logical" = String(",editor:") + "new Ext.form.ComboBox({typeAhead: true,editable: false,triggerAction: 'all',store: ['true','false'],lazyRender:true,listClass: 'x-combo-list-small'})",
+           "factor" = String(",editor:") + "new Ext.form.ComboBox({typeAhead: true,editable: false,triggerAction: 'all',store: [" + paste(shQuote(levels(x)),collapse=",") + "],lazyRender:true,listClass: 'x-combo-list-small'})",
+           "date" = "",               # we create this?
+           ",editor: new Ext.form.TextField()") # default is text
+  }
 
   widget$makeColumnModel <- function(.) {
     ## return array for columns
@@ -131,19 +148,9 @@ gdf <- function(items = NULL, name = deparse(substitute(items)),
 ##               {header: "Last Updated", sortable: true, renderer: Ext.util.Format.dateRenderer('m/d/Y'), dataIndex: 'lastChange'}
 ##               ],
 
-    mapEditor <- function(x) {
-      type <- class(x)[1]
-      switch(type,
-             "integer" = ",editor: new Ext.form.NumberField({allowBlank: true,allowDecimals: false,nanText: 'NA'})",
-             "numeric" = ",editor: new Ext.form.NumberField({allowBlank: true,allowDecimals: true,nanText: 'NA'})",
-             "logical" = String(",editor:") + "new Ext.form.ComboBox({typeAhead: true,editable: false,triggerAction: 'all',store: ['true','false'],lazyRender:true,listClass: 'x-combo-list-small'})",
-             "factor" = String(",editor:") + "new Ext.form.ComboBox({typeAhead: true,editable: false,triggerAction: 'all',store: [" + paste(shQuote(levels(x)),collapse=",") + "],lazyRender:true,listClass: 'x-combo-list-small'})",
-             "date" = "",               # we create this?
-             ",editor: new Ext.form.TextField()") # default is text
-    }
 
     df <- .$..store$data
-    editors <- sapply(df, function(i) mapEditor(i))
+    editors <- sapply(df, function(i) .$mapEditor(i))
     colNames <- names(df)
     colNames <- shQuoteEsc(colNames)
 
@@ -152,6 +159,8 @@ gdf <- function(items = NULL, name = deparse(substitute(items)),
                  'id:',colNames,
                  ', header:',colNames,
                  ', sortable:true',
+                 if(!.$has_slot("..columnWidths")) "" else 
+                        sprintf(", width: %s",rep(.$..columnWidths, length.out=ncol(df))),
                  ', dataIndex:',colNames,
                  editors,
                  '}',
@@ -198,7 +207,7 @@ gdf <- function(items = NULL, name = deparse(substitute(items)),
 
   ## handler definitions
   widget$addHandlerChanged <- function(., handler, action = NULL, ...)
-    widget$addHandler(signal = "afteredit", handler, action=action, ...)
+    .$addHandler(signal = "afteredit", handler, action=action, ...)
   
   invisible(widget)
   
