@@ -1,3 +1,20 @@
+##  Copyright (C) 2010 John Verzani
+##
+##  This program is free software; you can redistribute it and/or modify
+##  it under the terms of the GNU General Public License as published by
+##  the Free Software Foundation; either version 2 of the License, or
+##  (at your option) any later version.
+##
+##  This program is distributed in the hope that it will be useful,
+##  but WITHOUT ANY WARRANTY; without even the implied warranty of
+##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+##  GNU General Public License for more details.
+##
+##  A copy of the GNU General Public License is available at
+##  http://www.r-project.org/Licenses/
+
+## DEPRECATED
+
 ## Simple interface to googlemaps
 
 ## Can show a map with some programmatic markup possible
@@ -16,7 +33,7 @@
 ggooglemaps <- function(x, title = "",  type = c("map","panorama"),
                         key="ABQIAAAAYpRTbDoR3NFWvhN4JrY1ahS5eHnalTx_x--TpGz1e2ncErJceBS7FrNBqzV5DPxkpbheIzZ9nTJPsQ", # for 127.0.0.1:8079; only for local. For server, set in RApache.conf
                         container, ...) {
-
+  
   return(glabel("XXX This needs updating to version 3 of ggoglemaps", cont=container))
 
   
@@ -152,7 +169,7 @@ widget$makeMarkers <- function(.) {
     return(out)
   }
 
-  widget$setValueJS <- function(.) {
+  widget$setValueJS <- function(., ...) {
     value <- svalue(.)
     if(length(value) == 2)
       .$panTo(value)
@@ -215,7 +232,7 @@ widget$makeMarkers <- function(.) {
           'new GLatLng(' + latlng[1] + ',' + latlng[2] + '));'
 
     if(exists("..shown", envir=., inherits = FALSE))
-      cat(out)
+      .$addJSQueue(out)
     else
       .$setValue(value = latlng)
   }
@@ -226,7 +243,7 @@ widget$makeMarkers <- function(.) {
         .$gmapID() + '.setZoom(' + zoom + ');'
 
     if(exists("..shown", envir=., inherits = FALSE))
-      cat(out)
+      .$addJSQueue(out)
     else
       .$..zoomLevel <- zoom
 
@@ -241,7 +258,7 @@ widget$makeMarkers <- function(.) {
             shQuoteEsc(myHTML) + ');'
 
     if(exists("..shown", envir=., inherits = FALSE))
-      cat(out)
+      .$addJSQueue(out)
     else
       .$..runCmds <- c(.$..runCmds, out)
   }
@@ -292,7 +309,7 @@ widget$makeMarkers <- function(.) {
       .$gmapID() + '.addOverlay(marker);'
     
     if(exists("..shown", envir=., inherits = FALSE))
-      cat(out)
+      .$addJSQueue(out)
     else
       .$..runCmds <- c(.$..runCmds, out)
   }
@@ -330,7 +347,7 @@ widget$makeMarkers <- function(.) {
       .$gmapID() + '.addOverlay(polyline);'
 
     if(exists("..shown", envir=., inherits = FALSE))
-      cat(out)
+      .$addJSQueue(out)
     else
       .$..runCmds <- c(.$..runCmds, out)
   }
@@ -381,7 +398,7 @@ widget$makeMarkers <- function(.) {
       .$gmapID() + '.addOverlay(polygon);'
 
     if(exists("..shown", envir=., inherits = FALSE))
-      cat(out)
+      .$addJSQueue(out)
     else
       .$..runCmds <- c(.$..runCmds, out)
   }
