@@ -1,7 +1,37 @@
+##  Copyright (C) 2010 John Verzani
+##
+##  This program is free software; you can redistribute it and/or modify
+##  it under the terms of the GNU General Public License as published by
+##  the Free Software Foundation; either version 2 of the License, or
+##  (at your option) any later version.
+##
+##  This program is distributed in the hope that it will be useful,
+##  but WITHOUT ANY WARRANTY; without even the implied warranty of
+##  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+##  GNU General Public License for more details.
+##
+##  A copy of the GNU General Public License is available at
+##  http://www.r-project.org/Licenses/
+
 ## Works as of Ext-3.0
 ## why are there no arrows???
 
 ## others
+
+##' Basic spinbutton
+##'
+##' For some reason the images don't work!
+##' @param from from value
+##' @param to to
+##' @param by by. From to by are same as seq() usage
+##' @param value initial value
+##' @param handler handler for when change is made
+##' @param action passed to the handler, if given
+##' @param container parent container
+##' @param ... passed to add method of parent
+##' @export
+##' @examples /Tests/test-gspinbutton.R
+##' @TODO get icons working. Not sure why they dont (positioning is the likely culprit)
 gspinbutton <- function(from = 0, to = 100, by = 1, value = from,
                     handler = NULL, action = NULL, container = NULL, ...) {
   widget <- EXTComponent$new(toplevel=container$toplevel,
@@ -10,6 +40,12 @@ gspinbutton <- function(from = 0, to = 100, by = 1, value = from,
   class(widget) <- c("gSpinbutton",class(widget))
   widget$setValue(value=value)
   widget$..coerce.with="as.numeric"
+
+  ## no index
+  widget$assignValue <- function(., value) {
+    .$..data <- as.numeric(value[[1]])
+  }
+
   ## CSS
   ## XXX Get this css to work to get trigger icon for spin
   ##   widget$css <- function(.) {
@@ -21,11 +57,11 @@ gspinbutton <- function(from = 0, to = 100, by = 1, value = from,
   widget$css <- function(.) {
     ## can't have comments etc., as this goes into one line.
     out <- paste(
-                 ".x-form-spinner-proxy{",
-                 "/*background-color:#ff00cc;*/",
-                 "}",
+#                 ".x-form-spinner-proxy{",
+#                 "/*background-color:#ff00cc;*/",
+#                 "}",
                  ".x-form-field-wrap .x-form-spinner-trigger {",
-                   "background:transparent url('../images/spinner.gif') no-repeat 0 0;",
+                   sprintf("background:transparent url('%s/spinner.gif') no-repeat 0 0;",gWidgetsWWWimageUrl),
                  "}",
                  ".x-form-field-wrap .x-form-spinner-overup{",
                  "background-position:-17px 0;",
@@ -63,7 +99,7 @@ gspinbutton <- function(from = 0, to = 100, by = 1, value = from,
                  ".x-form-field-wrap .x-form-spinner-splitter {",
                  "line-height:1px;",
                  "font-size:1px;",
-                 "background:transparent url('../images/spinner-split.gif') no-repeat 0 0;",
+                 sprintf("background:transparent url('%s/spinner-split.gif') no-repeat 0 0;",gWidgetsWWWimageUrl),
                  "position:absolute;",
                  "cursor: n-resize;",
                "}",
@@ -73,21 +109,6 @@ gspinbutton <- function(from = 0, to = 100, by = 1, value = from,
                  sep="")
     return(out)
   }
-  
-  widget$scripts <- function(.) {
-    out <- String()
-
-    ## These should be in a javascript directory on the web server,
-    ## but this is easier (slower too as it doesn't cache)
-    f <- system.file("javascript","ext.ux.spinner.js", package="gWidgetsWWW")
-    out <- out + "\n" + paste(readLines(f), collapse="\n")
-    
-    f <- system.file("javascript","ext.ux.spinnerformfield.js", package="gWidgetsWWW")
-    out <- out + "\n" + paste(readLines(f), collapse="\n")
-    
-    return(out)
-  }
-  
   ## methods
   widget$getValueJSMethod <- "getValue"
 
@@ -114,9 +135,12 @@ gspinbutton <- function(from = 0, to = 100, by = 1, value = from,
   ## add after CSS, scripts defined
   container$add(widget,...)
 
+  widget$addHandlerChanged <- function(., handler, action=NULL) 
+    .$addHandler(signal="spin",handler, action)
+  
 
   if(!is.null(handler))
-    widget$addHandler("change",handler=handler,action=action)
+    addHandlerChanged(widget, handler, action)
   
   invisible(widget)
 }
