@@ -1,3 +1,5 @@
+## Example of gfieldset widget to make a form
+
 w <- gwindow("An example form")
 g <- ggroup(horiz=FALSE, cont = w)
 
@@ -33,8 +35,7 @@ bg <- ggroup(cont = g)
 gbutton("ok", cont = bg, handler = function(h,...) {
   vals <- svalue(f)
   out <- paste(capture.output(str(vals)), collapse="<br>")
-#  out <- paste(names(vals),unlist(vals), sep="=", collapse="<br>")
-  galert(out)
+  galert(out, parent=w)
   
 })
 
